ZipRequestError class

author:郑再红 email:1096877329@qq.com date:2026-06-02 11:28 describe:带有上下文的请求错误包装器 Wrapper for request errors with context

Constructors

ZipRequestError({required int index, String? tag, required dynamic error, StackTrace? stackTrace})

Properties

error → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
index int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
final
tag String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited