ContentTypes class

author: ZhengZaiHong email:1096877329@qq.com date: 2025/8/24 time: 18:29 describe: Content-Type 类型

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom(String mimeType) String
可扩展自定义类型

Constants

csv → const String
eventStream → const String
formUrlEncoded → const String
gif → const String
graphql → const String
html → const String
javascript → const String
jpeg → const String
json → const String
multipartFormData → const String
ndJson → const String
octetStream → const String
pdf → const String
plainText → const String
png → const String
svg → const String
xml → const String
zip → const String