RetryStrategy enum

author:郑再红 email:1096877329@qq.com date:2026-08-05 15:47 describe: 重试策略枚举

Inheritance
Available extensions

Values

fixed → const RetryStrategy

固定间隔重试(默认行为)

exponentialBackoff → const RetryStrategy

指数退避重试

exponentialBackoffWithJitter → const RetryStrategy

指数退避 + 随机抖动重试

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RetryStrategy>
A constant List of the values in this enum, in order of their declaration.