RequestState<T> class
author:ZhengZaiHong email:1096877329@qq.com date:2026-06-02 11:27 describe: 跟踪请求执行的内部状态 Internal state for tracking request execution
Constructors
-
RequestState({required ZipRequest<
T> request, required Completer<T> completer, required int index})
Properties
-
completer
→ Completer<
T> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
final
- isCompleted → bool
-
no setter
-
request
→ ZipRequest<
T> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited